
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef sick_MSG_LIB_H
#define sick_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "sickType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  SICK_MBOX_NAME                  genomInstanceName("sick")

#define  SICK_MAX_RQST_SIZE              272

#define  SICK_MBOX_RQST_SIZE       \
 (BUF_SIZE(SICK_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  SICK_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  SICK_MAX_REPLY_SIZE             272

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  SICK_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(SICK_MAX_REPLY_SIZE) \
   + BUF_SIZE(SICK_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define SICK_INIT_RQST 0
#define SICK_SETPOSTAGGING_RQST 1
#define SICK_SETSICKPOSONROBOT_RQST 2
#define SICK_INITPARAMSGET_RQST 3
#define SICK_RESET_RQST 4
#define SICK_EXPORTDATA_RQST 5
#define SICK_EXPORTDATAGET_RQST 6
#define SICK_ONESHOOT_RQST 7
#define SICK_CONTINUOUSSHOT_RQST 8
#define SICK_SICKACQCONFIG_RQST 9
#define SICK_SICKACQCONFIGGET_RQST 10
#define SICK_SETSYNCHROTUNNING_RQST 11
#define SICK_GETSYNCHROTUNNING_RQST 12
#define SICK_GETSEGMENTATIONPARAMS_RQST 13
#define SICK_SETSEGMENTATIONPARAMS_RQST 14
#define SICK_GETSICKDATAFILES_RQST 15
#define SICK_SAVE_RQST 16
#define SICK_SETSICKDATAFILES_RQST 17
#define SICK_SETENVFILENAME_RQST 18
#define SICK_GETENVFILENAME_RQST 19
#define SICK_LOG_RQST 20
#define SICK_STOPLOG_RQST 21
#define SICK_ABORT_RQST 22


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS sickClientInit (CLIENT_ID *pClientId);

STATUS sickClientEnd (CLIENT_ID clientId);

int sickAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int sickAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int sickAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS sickInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SICK_INIT_PARAMS *(in_initParams),
					 int replyTimeOut);

extern int sickInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int sickInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SICK_INIT_PARAMS *(in_initParams), 
					
					int *activity, int *bilan);

extern int sickInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SICK_INIT_PARAMS *(in_initParams), 
					
					int *activity,
					int *bilan);




extern STATUS sickSetPosTaggingRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SICK_STRING *(in_sickPosPosterName),
					 int replyTimeOut);

int sickSetPosTaggingReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickSetPosTaggingRqstAndRcv (CLIENT_ID clientId, 
				 SICK_STRING *(in_sickPosPosterName), 
				 
				 int *bilan);




extern STATUS sickSetSickPosOnRobotRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 POM_EULER *(in_sickPosOnRobot),
					 int replyTimeOut);

int sickSetSickPosOnRobotReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickSetSickPosOnRobotRqstAndRcv (CLIENT_ID clientId, 
				 POM_EULER *(in_sickPosOnRobot), 
				 
				 int *bilan);




extern STATUS sickInitParamsGetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickInitParamsGetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SICK_INIT_PARAMS *(out_initParams),
			       int *bilan);

int sickInitParamsGetRqstAndRcv (CLIENT_ID clientId, 
				  
				 SICK_INIT_PARAMS *(out_initParams),
				 int *bilan);




extern STATUS sickResetRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int sickResetReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int sickResetRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int sickResetRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS sickExportDataRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SICK_EXPORT_DATA *(in_exportData),
					 int replyTimeOut);

int sickExportDataReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickExportDataRqstAndRcv (CLIENT_ID clientId, 
				 SICK_EXPORT_DATA *(in_exportData), 
				 
				 int *bilan);




extern STATUS sickExportDataGetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickExportDataGetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SICK_EXPORT_DATA *(out_exportData),
			       int *bilan);

int sickExportDataGetRqstAndRcv (CLIENT_ID clientId, 
				  
				 SICK_EXPORT_DATA *(out_exportData),
				 int *bilan);




extern STATUS sickOneShootRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int sickOneShootReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int sickOneShootRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int sickOneShootRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS sickContinuousShotRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SICK_SCAN_MODES *(in_scan_mode),
					 int replyTimeOut);

extern int sickContinuousShotReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int sickContinuousShotRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SICK_SCAN_MODES *(in_scan_mode), 
					
					int *activity, int *bilan);

extern int sickContinuousShotRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SICK_SCAN_MODES *(in_scan_mode), 
					
					int *activity,
					int *bilan);




extern STATUS sickSickAcqConfigRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SICK_USER_STR *(in_user_config),
					 int replyTimeOut);

extern int sickSickAcqConfigReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      SICK_CONFIG_STR *(out_sick_config),
				      int *activity, int *bilan);


extern int sickSickAcqConfigRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SICK_USER_STR *(in_user_config), 
					SICK_CONFIG_STR *(out_sick_config),
					int *activity, int *bilan);

extern int sickSickAcqConfigRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SICK_USER_STR *(in_user_config), 
					SICK_CONFIG_STR *(out_sick_config),
					int *activity,
					int *bilan);




extern STATUS sickSickAcqConfigGetRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickSickAcqConfigGetReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SICK_USER_STR *(out_user_config),
			       int *bilan);

int sickSickAcqConfigGetRqstAndRcv (CLIENT_ID clientId, 
				  
				 SICK_USER_STR *(out_user_config),
				 int *bilan);




extern STATUS sickSetSynchroTunningRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_synchroPosTunning),
					 int replyTimeOut);

int sickSetSynchroTunningReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickSetSynchroTunningRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_synchroPosTunning), 
				 
				 int *bilan);




extern STATUS sickGetSynchroTunningRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickGetSynchroTunningReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       int *(out_synchroPosTunning),
			       int *bilan);

int sickGetSynchroTunningRqstAndRcv (CLIENT_ID clientId, 
				  
				 int *(out_synchroPosTunning),
				 int *bilan);




extern STATUS sickGetSegmentationParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickGetSegmentationParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SICK_SEG_PARAMS *(out_segParams),
			       int *bilan);

int sickGetSegmentationParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 SICK_SEG_PARAMS *(out_segParams),
				 int *bilan);




extern STATUS sickSetSegmentationParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SICK_SEG_PARAMS *(in_segParams),
					 int replyTimeOut);

int sickSetSegmentationParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickSetSegmentationParamsRqstAndRcv (CLIENT_ID clientId, 
				 SICK_SEG_PARAMS *(in_segParams), 
				 
				 int *bilan);




extern STATUS sickGetSickDataFilesRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickGetSickDataFilesReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SICK_SAVE_FILE_PARAMS *(out_saveFileParams),
			       int *bilan);

int sickGetSickDataFilesRqstAndRcv (CLIENT_ID clientId, 
				  
				 SICK_SAVE_FILE_PARAMS *(out_saveFileParams),
				 int *bilan);




extern STATUS sickSaveRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SICK_SAVE_FILE_PARAMS *(in_saveFileParams),
					 int replyTimeOut);

extern int sickSaveReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int sickSaveRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SICK_SAVE_FILE_PARAMS *(in_saveFileParams), 
					
					int *activity, int *bilan);

extern int sickSaveRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SICK_SAVE_FILE_PARAMS *(in_saveFileParams), 
					
					int *activity,
					int *bilan);




extern STATUS sickSetSickDataFilesRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SICK_SAVE_FILE_PARAMS *(in_saveFileParams),
					 int replyTimeOut);

int sickSetSickDataFilesReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickSetSickDataFilesRqstAndRcv (CLIENT_ID clientId, 
				 SICK_SAVE_FILE_PARAMS *(in_saveFileParams), 
				 
				 int *bilan);




extern STATUS sickSetEnvFileNameRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GEN_STRING256 *(in_envFileName),
					 int replyTimeOut);

int sickSetEnvFileNameReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickSetEnvFileNameRqstAndRcv (CLIENT_ID clientId, 
				 GEN_STRING256 *(in_envFileName), 
				 
				 int *bilan);




extern STATUS sickGetEnvFileNameRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickGetEnvFileNameReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GEN_STRING256 *(out_envFileName),
			       int *bilan);

int sickGetEnvFileNameRqstAndRcv (CLIENT_ID clientId, 
				  
				 GEN_STRING256 *(out_envFileName),
				 int *bilan);




extern STATUS sickLogRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_logFileName),
					 int replyTimeOut);

extern int sickLogReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int sickLogRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_logFileName), 
					
					int *activity, int *bilan);

extern int sickLogRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_logFileName), 
					
					int *activity,
					int *bilan);




extern STATUS sickStopLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int sickStopLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int sickStopLogRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* sick_MSG_LIB_H */

